@@ -36,9 +36,11 @@ def append_hash_to_fn(fn, hash_value):
     return ext_re.sub(r"\1_{}\2".format(hash_value[:10]), fn)
 
 
-def download_to_cache(cache_folder, recipe_path, source_dict):
+def download_to_cache(cache_folder, recipe_path, source_dict, verbose=False):
     ''' Download a source to the local cache. '''
-    print('Source cache directory is: %s' % cache_folder)
+    log = get_logger(__name__)
+    if verbose:
+        log.info('Source cache directory is: %s' % cache_folder)
     if not isdir(cache_folder):
         os.makedirs(cache_folder)
 
@@ -53,14 +55,15 @@ def download_to_cache(cache_folder, recipe_path, source_dict):
             hash_added = True
             break
     else:
-        log = get_logger(__name__)
         log.warn("No hash (md5, sha1, sha256) provided for {}.  Source download forced.  "
                  "Add hash to recipe to use source cache.".format(unhashed_fn))
     path = join(cache_folder, fn)
     if isfile(path):
-        print('Found source in cache: %s' % fn)
+        if verbose:
+            log.info('Found source in cache: %s' % fn)
     else:
-        print('Downloading source to cache: %s' % fn)
+        if verbose:
+            log.info('Downloading source to cache: %s' % fn)
 
         for url in source_urls:
             if "://" not in url:
@@ -73,17 +76,19 @@ def download_to_cache(cache_folder, recipe_path, source_dict):
                 if url.startswith('file:///~'):
                     url = 'file:///' + expanduser(url[8:]).replace('\\', '/')
             try:
-                print("Downloading %s" % url)
+                if verbose:
+                    log.info("Downloading %s" % url)
                 with LoggingContext():
                     download(url, path)
             except CondaHTTPError as e:
-                print("Error: %s" % str(e).strip(), file=sys.stderr)
+                log.warn("Error: %s" % str(e).strip())
                 rm_rf(path)
             except RuntimeError as e:
-                print("Error: %s" % str(e).strip(), file=sys.stderr)
+                log.warn("Error: %s" % str(e).strip())
                 rm_rf(path)
             else:
-                print("Success")
+                if verbose:
+                    log.info("Success")
                 break
         else:  # no break
             rm_rf(path)
@@ -131,7 +136,7 @@ def hoist_single_extracted_folder(nested_folder):
 def unpack(source_dict, src_dir, cache_folder, recipe_path, croot, verbose=False,
            timeout=900, locking=True):
     ''' Uncompress a downloaded source. '''
-    src_path, unhashed_fn = download_to_cache(cache_folder, recipe_path, source_dict)
+    src_path, unhashed_fn = download_to_cache(cache_folder, recipe_path, source_dict, verbose)
 
     if not isdir(src_dir):
         os.makedirs(src_dir)
@@ -297,12 +302,14 @@ def git_source(source_dict, git_cache, src_dir, recipe_path=None, verbose=True):
 
     git = external.find_executable('git')
     if not git:
-        sys.exit("Error: git is not installed in your root environment.")
+        sys.exit("Error: git is not installed in your root environment or as a build requirement.")
 
-    git_url = source_dict['git_url']
     git_depth = int(source_dict.get('git_depth', -1))
     git_ref = source_dict.get('git_rev') or 'HEAD'
 
+    git_url = source_dict['git_url']
+    if git_url.startswith('~'):
+        git_url = os.path.expanduser(git_url)
     if git_url.startswith('.'):
         # It's a relative path from the conda recipe
         git_url = abspath(normpath(os.path.join(recipe_path, git_url)))
@@ -545,6 +552,14 @@ def apply_patch(src_dir, path, config, git=None):
     if not isfile(path):
         sys.exit('Error: no such patch: %s' % path)
 
+    if config.verbose:
+        stdout = None
+        stderr = None
+    else:
+        FNULL = open(os.devnull, 'w')
+        stdout = FNULL
+        stderr = FNULL
+
     files, is_git_format = _get_patch_file_details(path)
     if git and is_git_format:
         # Prevents git from asking interactive questions,
@@ -556,10 +571,11 @@ def apply_patch(src_dir, path, config, git=None):
         git_env['GIT_COMMITTER_NAME'] = 'conda-build'
         git_env['GIT_COMMITTER_EMAIL'] = 'conda@conda-build.org'
         check_call_env([git, 'am', '--committer-date-is-author-date', path],
-                       cwd=src_dir, stdout=None, env=git_env)
+                       cwd=src_dir, stdout=stdout, stderr=stderr, env=git_env)
         config.git_commits_since_tag += 1
     else:
-        print('Applying patch: %r' % path)
+        if config.verbose:
+            print('Applying patch: %r' % path)
         patch = external.find_executable('patch', config.build_prefix)
         if patch is None:
             sys.exit("""\
@@ -576,24 +592,27 @@ def apply_patch(src_dir, path, config, git=None):
 
         try:
             log = get_logger(__name__)
-            log.info("Trying to apply patch as-is")
-            check_call_env([patch] + patch_args, cwd=src_dir)
+            if config.verbose:
+                log.info("Trying to apply patch as-is")
+            check_call_env([patch] + patch_args, cwd=src_dir, stdout=stdout, stderr=stderr)
         except CalledProcessError:
             if sys.platform == 'win32':
                 unix_ending_file = _ensure_unix_line_endings(path)
                 patch_args[-1] = unix_ending_file
                 try:
-                    log.info("Applying unmodified patch failed.  "
-                             "Convert to unix line endings and trying again.")
-                    check_call_env([patch] + patch_args, cwd=src_dir)
+                    if config.verbose:
+                        log.info("Applying unmodified patch failed.  "
+                                "Convert to unix line endings and trying again.")
+                    check_call_env([patch] + patch_args, cwd=src_dir, stdout=stdout, stderr=stderr)
                 except:
-                    log.info("Applying unix patch failed.  "
-                             "Convert to CRLF line endings and trying again with --binary.")
+                    if config.verbose:
+                        log.info("Applying unix patch failed.  "
+                                "Convert to CRLF line endings and trying again with --binary.")
                     patch_args.insert(0, '--binary')
                     win_ending_file = _ensure_win_line_endings(path)
                     patch_args[-1] = win_ending_file
                     try:
-                        check_call_env([patch] + patch_args, cwd=src_dir)
+                        check_call_env([patch] + patch_args, cwd=src_dir, stdout=stdout, stderr=stderr)
                     except:
                         raise
                     finally:
@@ -659,10 +678,8 @@ def provide(metadata):
                     os.makedirs(src_dir)
 
             patches = ensure_list(source_dict.get('patches', []))
-            recipe_dir = (metadata.path or
-                          metadata.meta.get('extra', {}).get('parent_recipe', {}).get('path', ''))
             for patch in patches:
-                apply_patch(src_dir, join(recipe_dir, patch), metadata.config, git)
+                apply_patch(src_dir, join(metadata.path, patch), metadata.config, git)
 
     except CalledProcessError:
         shutil.move(metadata.config.work_dir, metadata.config.work_dir + '_failed_provide')
