@@ -258,9 +258,40 @@ def _write_bat_activation_text(file_handle, m):
             prefix=m.config.build_prefix))
 
 
-def build(m, bld_bat, stats):
-    with path_prepended(m.config.build_prefix):
-        with path_prepended(m.config.host_prefix):
+def write_build_scripts(m, env, bld_bat):
+    env_script = join(m.config.work_dir, 'build_env_setup.bat')
+    with open(env_script, 'w') as fo:
+        # more debuggable with echo on
+        fo.write('@echo on\n')
+        for key, value in env.items():
+            if value:
+                fo.write('set "{key}={value}"\n'.format(key=key, value=value))
+        if not m.uses_new_style_compiler_activation:
+            fo.write(msvc_env_cmd(bits=m.config.host_arch, config=m.config,
+                                override=m.get_value('build/msvc_compiler', None)))
+        # Reset echo on, because MSVC scripts might have turned it off
+        fo.write('@echo on\n')
+        fo.write('set "INCLUDE={};%INCLUDE%"\n'.format(env["LIBRARY_INC"]))
+        fo.write('set "LIB={};%LIB%"\n'.format(env["LIBRARY_LIB"]))
+        if m.config.activate and m.name() != 'conda':
+            _write_bat_activation_text(fo, m)
+    # bld_bat may have been generated elsewhere with contents of build/script
+    work_script = join(m.config.work_dir, 'conda_build.bat')
+    if os.path.isfile(bld_bat):
+        with open(bld_bat) as fi:
+            data = fi.read()
+        with open(work_script, 'w') as fo:
+            fo.write('IF "%CONDA_BUILD%" == "" (\n')
+            fo.write("    call {}\n".format(env_script))
+            fo.write(')\n')
+            fo.write("REM ===== end generated header =====\n")
+            fo.write(data)
+    return work_script, env_script
+
+
+def build(m, bld_bat, stats, provision_only=False):
+    with path_prepended(m.config.host_prefix):
+        with path_prepended(m.config.build_prefix):
             env = environ.get_dict(m=m)
     env["CONDA_BUILD_STATE"] = "BUILD"
 
@@ -283,6 +314,10 @@ def build(m, bld_bat, stats):
     # set PIP_CACHE_DIR to a path in the work dir that does not exist.
     env['PIP_CACHE_DIR'] = m.config.pip_cache_dir
 
+    # tell pip to not get anything from PyPI, please.  We have everything we need
+    # locally, and if we don't, it's a problem.
+    env["PIP_NO_INDEX"] = True
+
     # set variables like CONDA_PY in the test environment
     env.update(set_language_env_vars(m.config.variant))
 
@@ -291,29 +326,10 @@ def build(m, bld_bat, stats):
         if not isdir(path):
             os.makedirs(path)
 
-    src_dir = m.config.work_dir
-    if os.path.isfile(bld_bat):
-        with open(bld_bat) as fi:
-            data = fi.read()
-        with open(join(src_dir, 'bld.bat'), 'w') as fo:
-            # more debuggable with echo on
-            fo.write('@echo on\n')
-            for key, value in env.items():
-                if value:
-                    fo.write('set "{key}={value}"\n'.format(key=key, value=value))
-            if not m.uses_new_style_compiler_activation:
-                fo.write(msvc_env_cmd(bits=m.config.host_arch, config=m.config,
-                                    override=m.get_value('build/msvc_compiler', None)))
-            # Reset echo on, because MSVC scripts might have turned it off
-            fo.write('@echo on\n')
-            fo.write('set "INCLUDE={};%INCLUDE%"\n'.format(env["LIBRARY_INC"]))
-            fo.write('set "LIB={};%LIB%"\n'.format(env["LIBRARY_LIB"]))
-            if m.config.activate and m.name() != 'conda':
-                _write_bat_activation_text(fo, m)
-            fo.write("REM ===== end generated header =====\n")
-            fo.write(data)
+    work_script, env_script = write_build_scripts(m, env, bld_bat)
 
-        cmd = ['cmd.exe', '/c', 'bld.bat']
+    if not provision_only and os.path.isfile(work_script):
+        cmd = ['cmd.exe', '/c', os.path.basename(work_script)]
         # rewrite long paths in stdout back to their env variables
         if m.config.debug:
             rewrite_env = None
@@ -323,6 +339,5 @@ def build(m, bld_bat, stats):
                 for k in ['PREFIX', 'BUILD_PREFIX', 'SRC_DIR'] if k in env
             }
             print("Rewriting env in output: %s" % pprint.pformat(rewrite_env))
-        check_call_env(cmd, cwd=src_dir, stats=stats, rewrite_stdout_env=rewrite_env)
-
-    fix_staged_scripts(join(m.config.host_prefix, 'Scripts'), config=m.config)
+        check_call_env(cmd, cwd=m.config.work_dir, stats=stats, rewrite_stdout_env=rewrite_env)
+        fix_staged_scripts(join(m.config.host_prefix, 'Scripts'), config=m.config)
